@@ -181,8 +181,16 @@ class Element:
                 return ElementCheckbox.create(params)
             elif params["type"] == "datepicker":
                 return ElementDatepicker.create(params)
-            elif params['type'] == "mrkdwn" or params['type'] == "plain_text":
-                return ObjectText.createU(params)
+            elif params["type"] == "timepicker":
+                return ElementTimepicker.create(params)
+            elif params["type"] == "image":
+                return ElementImage.create(params)
+            elif params["type"] == "plain_text_input":
+                return ElementPlainTextInput.create(params)
+            elif params["type"] == "static_select":
+                return ElementSelectWithStatic.create(params)
+            elif params["type"] == "mrkdwn" or params["type"] == "plain_text":
+                return ObjectText.create(params)
 
 
 class ElementButton(Element):
@@ -323,6 +331,51 @@ class ElementDatepicker(Element):
         )
 
 
+class ElementTimepicker(Element):
+    TYPE = "timepicker"
+
+    def __init__(
+        self,
+        action_id: str,
+        placeholder: Union[ObjectText, str] = None,
+        initial_time: str = None,
+        confirm: ObjectConfirmationDialog = None,
+    ):
+        super().__init__(self.TYPE)
+        self.action_id = action_id
+        self.placeholder = (
+            ObjectPlainText(placeholder) if type(placeholder) is str else placeholder
+        )
+        self.initial_time = initial_time
+        self.confirm = confirm
+
+    def getDict(self):
+        payload = super().getDict()
+        payload["action_id"] = self.action_id
+        if self.placeholder is not None:
+            payload["placeholder"] = self.placeholder.getDict()
+        if self.initial_time is not None:
+            payload["initial_time"] = self.initial_time
+        if self.confirm is not None:
+            payload["confirm"] = self.confirm.getDict()
+        return payload
+
+    @classmethod
+    def create(cls, params: dict) -> Element:
+        return ElementTimepicker(
+            action_id=params["action_id"],
+            placeholder=None
+            if not "placeholder" in params
+            else ObjectText.create(params["placeholder"]),
+            initial_time=None
+            if not "initial_time" in params
+            else params["initial_time"],
+            confirm=None
+            if not "confirm" in params
+            else ObjectConfirmationDialog.create(params["confirm"]),
+        )
+
+
 class ElementImage(Element):
     TYPE = "image"
 
@@ -641,6 +694,7 @@ class BlockDivider(Block):
 
 class BlockImage(Block):
     TYPE = "image"
+
     def __init__(
         self,
         image_url: str,
@@ -665,13 +719,14 @@ class BlockImage(Block):
         return BlockImage(
             image_url=params["image_url"],
             alt_text=params["alt_text"],
-            title=None if not 'title' in params else ObjectText.create(params['title']),
-            block_id=None if not 'block_id' in params else params['block_id']
+            title=None if not "title" in params else ObjectText.create(params["title"]),
+            block_id=None if not "block_id" in params else params["block_id"],
         )
 
 
 class BlockAction(Block):
-    TYPE="actions"
+    TYPE = "actions"
+
     def __init__(self, elements: List[Element], block_id: str = None):
         super().__init__(self.TYPE, block_id)
         self.elements = elements
@@ -685,14 +740,16 @@ class BlockAction(Block):
         return payload
 
     @classmethod
-    def create(cls, params:dict) -> Block:
+    def create(cls, params: dict) -> Block:
         return BlockAction(
-            elements=[Element.create(param) for param in params[elements]],
-            block_id = None if not 'block_id' in params else params['block_id']
+            elements=[Element.create(param) for param in params["elements"]],
+            block_id=None if not "block_id" in params else params["block_id"],
         )
 
+
 class BlockContext(Block):
-    TYPE="context"
+    TYPE = "context"
+
     def __init__(self, elements: List[Element], block_id: str = None):
         super().__init__(self.TYPE, block_id)
         self.elements = elements
@@ -706,14 +763,16 @@ class BlockContext(Block):
         return payload
 
     @classmethod
-    def create(cls, params:dict) -> Block:
+    def create(cls, params: dict) -> Block:
         return BlockContext(
-            elements=[Element.create(param) for param in params['elements']],
-            block_id = None if not 'block_id' in params else params['block_id']
+            elements=[Element.create(param) for param in params["elements"]],
+            block_id=None if not "block_id" in params else params["block_id"],
         )
 
+
 class BlockInput(Block):
-    TYPE="input"
+    TYPE = "input"
+
     def __init__(
         self,
         label: Union[ObjectText, str],
@@ -738,17 +797,19 @@ class BlockInput(Block):
         return payload
 
     @classmethod
-    def create(cls, params:dict) -> Block:
+    def create(cls, params: dict) -> Block:
         return BlockInput(
-            label = params['label'],
-            element=Element.create(params['element']),
-            block_id=None if not 'block_id' in params else params['block_id'],
-            hint=None if not 'hint' in params else ObjectText.create(params['hit']),
-            optional=False if not 'optional' in params else params['optional']
+            label=ObjectText.create( params["label"] ),
+            element=Element.create(params["element"]),
+            block_id=None if not "block_id" in params else params["block_id"],
+            hint=None if not "hint" in params else ObjectText.create(params["hit"]),
+            optional=False if not "optional" in params else params["optional"],
         )
 
+
 class BlockFile(Block):
-    TYPE="file"
+    TYPE = "file"
+
     def __init__(self, external_id: str, source: str, block_id: str = None):
         super().__init__(self.TYPE, block_id)
         self.external_id = external_id
@@ -757,20 +818,21 @@ class BlockFile(Block):
     def getDict(self):
         payload = super().getDict()
         payload["external_id"] = self.external_id
-        payload['source'] = self.source
+        payload["source"] = self.source
         return payload
 
     @classmethod
-    def create(cls, params:dict) -> Block:
+    def create(cls, params: dict) -> Block:
         return BlockFile(
-            external_id=params['external_id'],
-            source=params['source'],
-            block_id=None if not 'block_id' in params else params['block_id']
+            external_id=params["external_id"],
+            source=params["source"],
+            block_id=None if not "block_id" in params else params["block_id"],
         )
 
 
 class BlockHeader(Block):
-    TYPE="header"
+    TYPE = "header"
+
     def __init__(self, text: Union[ObjectPlainText, str], block_id: str = None):
         super().__init__(self.TYPE, block_id)
         self.text = ObjectPlainText(text) if type(text) is str else text
@@ -781,12 +843,13 @@ class BlockHeader(Block):
         return payload
 
     @classmethod
-    def create(cls, params:dict) -> Block:
+    def create(cls, params: dict) -> Block:
         return BlockHeader(
-            text = ObjectPlainText.create(params['text']),
-            block_id=None if not 'block_id' in params else params['blockid']
+            text=ObjectPlainText.create(params["text"]),
+            block_id=None if not "block_id" in params else params["block_id"],
         )
 
+
 """
 Block types
 """
@@ -803,8 +866,8 @@ class SlackBlocks:
             for block in blocks:
                 self.blocks.append(block)
         else:
-            for index , block in enumerate(blocks):
-                self.blocks.insert(position+index, block)
+            for index, block in enumerate(blocks):
+                self.blocks.insert(position + index, block)
 
     def clearBlocks(self, block_ids: List[str] = None):
         if block_ids == None:
@@ -812,9 +875,8 @@ class SlackBlocks:
         else:
             for id in block_ids:
                 for index, originalBlock in enumerate(self.blocks):
-                    if 'block_id' in originalBlock:
-                        if originalBlock['block_id'] == id:
-                            self.blocks.pop(index=index)
+                    if originalBlock.block_id == id:
+                            self.blocks.pop(index)
 
     def getDict(self):
         if self.type is not None:
@@ -827,41 +889,42 @@ class SlackBlocks:
     def getBlocks(self):
         return self.getDict()
 
-    def getPosition(self, block_id:int) -> int:
+    def getBlockParam(self, block_id) -> dict:
+        for block in self.blocks:
+            if block.block_id == block_id:
+                return block.getDict()
+        return None
+
+    def getPosition(self, block_id: str) -> int:
         for index, originalBlock in enumerate(self.blocks):
-            if 'block_id' in originalBlock:
-                if originalBlock['block_id'] == block_id:
-                    return index
+            if originalBlock.block_id == block_id:
+                return index
 
-
-
-    def parseBlocks(self, paramsList:List[dict]):
+    def parseBlocks(self, paramsList: List[dict]):
 
         creationClasses = [
-            {'type':BlockSection.TYPE, 'func':BlockSection.create},
-            {'type':BlockDivider.TYPE, 'func':BlockDivider.create},
-            {'type':BlockImage.TYPE, 'func':BlockImage.create},
-            {'type':BlockAction.TYPE, 'func':BlockAction.create},
-            {'type':BlockContext.TYPE, 'func':BlockContext.create},
-            {'type':BlockInput.TYPE, 'func':BlockInput.create},
-            {'type':BlockFile.TYPE, 'func':BlockFile.create},
-            {'type':BlockHeader.TYPE, 'func':BlockHeader.create},
+            {"type": BlockSection.TYPE, "func": BlockSection.create},
+            {"type": BlockDivider.TYPE, "func": BlockDivider.create},
+            {"type": BlockImage.TYPE, "func": BlockImage.create},
+            {"type": BlockAction.TYPE, "func": BlockAction.create},
+            {"type": BlockContext.TYPE, "func": BlockContext.create},
+            {"type": BlockInput.TYPE, "func": BlockInput.create},
+            {"type": BlockFile.TYPE, "func": BlockFile.create},
+            {"type": BlockHeader.TYPE, "func": BlockHeader.create},
         ]
         self.clearBlocks()
         for param in paramsList:
             for creationClass in creationClasses:
-                if param['type'] == creationClass['type']:
-                    block = creationClass['func'](param)
+                if param["type"] == creationClass["type"]:
+                    block = creationClass["func"](param)
                     if block != None:
                         self.blocks.append(block)
 
     def replaceBlock(self, blocks: List[Block]):
         for block in blocks:
-            if 'block_id' in block:
-                for index, originalBlock in enumerate(self.blocks):
-                    if 'block_id' in originalBlock:
-                        if originalBlock['block_id'] == block['block_id']:
-                            self.blocks[index] = block
+            for index, originalBlock in enumerate(self.blocks):
+                if originalBlock.block_id == block.block_id:
+                    self.blocks[index] = block
 
 
 class Message(SlackBlocks):
@@ -880,10 +943,11 @@ class Modal(SlackBlocks):
         callback_id: str = None,
         submit: Union[ObjectText, str] = None,
         close: Union[ObjectText, str] = None,
-        private_metadata: dict = {},
+        private_metadata: str = None,
         clear_on_close: bool = False,
         notify_on_close: bool = False,
         external_id: str = None,
+        submit_disabled : bool = False
     ):
         super().__init__("modal")
         self.title = ObjectPlainText(title) if type(title) is str else title
@@ -894,6 +958,7 @@ class Modal(SlackBlocks):
         self.clear_on_close = clear_on_close
         self.notify_on_close = notify_on_close
         self.external_id = external_id
+        self.submit_disable = submit_disabled
 
     def getDict(self):
         payload = super().getDict()
@@ -905,7 +970,7 @@ class Modal(SlackBlocks):
         if self.close is not None:
             payload["close"] = self.close.getDict()
         if self.private_metadata is not None:
-            payload["private_metadata"] = str(json.dumps(self.private_metadata))
+            payload["private_metadata"] = self.private_metadata
         payload["clear_on_close"] = self.clear_on_close
         payload["notify_on_close"] = self.notify_on_close
         if self.external_id is not None:
